#!/bin/sh

for n in "$@"; do case ${n%%=*} in
  data) _DATA="${n#data=}";;
  exec) _EXEC="${n#exec=}";;
  debug) DEBUG="${n#debug=}";;
esac; done

[ ! "${_EXEC%/}" ] && _EXEC="$(realpath "${0%/*}")" || _EXEC="${_EXEC%/}"
[ ! "${_DATA%/}" ] && _DATA=. || _DATA="${_DATA%/}"
[ "$DEBUG" ] && exec 2>>"$DEBUG"

mkdir -p "${_DATA}/cache" "${_DATA}/mappings" "${_DATA}/export" "${_DATA}/lock" "${_DATA}/ical" "${_DATA}/vcard"

debug() {
  local dbg=/dev/stderr
  if [ ! "$DEBUG" ]; then
    [ "$#" -gt 0 ] && : || cat;
  elif [ "$#" -gt 0 ]; then
    printf '%s\n' "$@" >>"$dbg"
  else
    tee -a "$dbg"
  fi
}

. "$_EXEC/cgilite/cgilite.sh"
. "$_EXEC/cgilite/session.sh"

. "$_EXEC/l10n.sh"

_PATH="$(PATH "/${PATH_INFO}")"
ACTION="$(GET a)"

message="$(COOKIE message)"
[ "$message" ] && SET_COOKIE 0 message=''

checked(){
  if [ "$1" = "$2" ] || [ "$1" -eq "$2" ]; then
    printf 'checked="checked"'
  fi 2>/dev/null
}
selected(){
  if [ "$1" = "$2" ] || [ "$1" -eq "$2" ]; then
    printf 'selected="selected"'
  fi 2>/dev/null
}

yield_page() {
  local class="$1" style="$2"
  printf 'Content-Type: text/html; charset=utf-8\r\n\r\n'
  { printf '
	[html [head
          [title Confetti]
	  [meta name="viewport" content="width=device-width"]
	  [link rel="stylesheet" type="text/css" href="/cgilite/common.css"]
	  [link rel="stylesheet" type="text/css" href="/style.css"]
    '
    [ -n "$style" ] && printf '
	  [link rel="stylesheet" type="text/css" href="%s"]
    ' "$style"
    printf '
	] [body #top class="%s"
    ' "$class"
    printf '[ul .menu [li [a "/cards/" . %s]][li [a "/courses/" . %s]]]' "$(l10n cards)" "$(l10n courses)"
    [ "$message" ] && printf '[p #message\n%s\n]' "$(l10n "$message")"
    cat
    printf '] ]'
  } \
  | "${_EXEC}/cgilite/html-sh.sed"
}

topdir="${_PATH#/}"
topdir="/${topdir%%/*}"

case ${_PATH} in
  /) REDIRECT /cards/
    ;;
  /export/*.pdf) . "$_EXEC/cgilite/file.sh"
    FILE "${_DATA}/${_PATH}" "application/pdf"
    ;;
  /export/*) . "$_EXEC/cgilite/file.sh"
    FILE "${_DATA}/${_PATH}"
    ;;
  *)
    if   [ -d "${_EXEC}/${_PATH}" -a -x "${_EXEC}/${_PATH}/index.cgi" ]; then
      . "${_EXEC}/${_PATH}/index.cgi"
    elif [ -f "${_EXEC}/${_PATH}" -a -x "${_EXEC}/${_PATH}" ]; then
      . "${_EXEC}/${_PATH}"
    elif [ -f "${_EXEC}/${_PATH}" -a -r "${_EXEC}/${_PATH}" ]; then
      . "$_EXEC/cgilite/file.sh"
      FILE "${_EXEC}/${_PATH}"
    elif [ -d "${_EXEC}/${topdir}" -a -x "${_EXEC}/${topdir}/index.cgi" ]; then
      . "${_EXEC}/${topdir}/index.cgi"
    else
      printf '%s\r\n' 'Status: 404 Not Found' 'Content-Length: 0' ''
    fi
    ;;
esac
